@@ -1,13 +1,20 @@
-""" InfluxDB Measurement. """
+"""
+InfluxDB Measurement.
+"""
 import six
-from . import meta
+
+from influxalchemy import meta
 
 
 # pylint: disable=too-few-public-methods
 class Measurement(six.with_metaclass(meta.MetaMeasurement)):
-    """ InfluxDB Measurement. """
+    """
+    InfluxDB Measurement.
+    """
     # pylint: disable=no-init
     @classmethod
     def new(cls, name):
-        """ Generate new Measurement class. """
+        """
+        Generate new Measurement class.
+        """
         return type(name, (cls,), {"__measurement__": name})
